@@ -18,17 +18,18 @@ Used to implement flexible fine-tuning training schedules
 """
 import logging
 from copy import deepcopy
+from pprint import pformat
 from typing import Any, Dict, Optional, Sequence, Union
 
-import pytorch_lightning as pl
+import lightning.pytorch as pl
 import torch
-from lightning_fabric.utilities import rank_zero_info
-from lightning_fabric.utilities.distributed import ReduceOp
-from pytorch_lightning.callbacks import BaseFinetuning
-from pytorch_lightning.strategies.strategy import Strategy
-from pytorch_lightning.trainer.states import TrainerFn
-from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.rank_zero import rank_zero_debug, rank_zero_warn
+from lightning.fabric.utilities import rank_zero_info
+from lightning.fabric.utilities.distributed import ReduceOp
+from lightning.pytorch.callbacks import BaseFinetuning
+from lightning.pytorch.strategies.strategy import Strategy
+from lightning.pytorch.trainer.states import TrainerFn
+from lightning.pytorch.utilities.exceptions import MisconfigurationException
+from lightning.pytorch.utilities.rank_zero import rank_zero_debug, rank_zero_warn
 from torch.optim.optimizer import Optimizer
 
 from finetuning_scheduler.fts_supporters import (
@@ -55,7 +56,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
 
     Fine-tuning phase transitions are driven by
     :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` criteria (a multi-phase
-    extension of :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`), user-specified epoch
+    extension of :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping`), user-specified epoch
     transitions or a composition of the two (the default mode). A
     :class:`~finetuning_scheduler.fts.FinetuningScheduler` training session completes
     when the final phase of the schedule has its stopping criteria met. See
@@ -71,9 +72,9 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
 
     Example::
 
-        from pytorch_lightning import Trainer
-        from pytorch_lightning.callbacks import FinetuningScheduler
-        trainer = Trainer(callbacks=[FinetuningScheduler()])
+        import lightning as L
+        from lightning.pytorch.callbacks import FinetuningScheduler
+        trainer = L.Trainer(callbacks=[FinetuningScheduler()])
 
     .. note::
 
@@ -104,6 +105,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         allow_untested: bool = False,
         apply_lambdas_new_pgs: bool = False,
         logging_level: int = logging.INFO,
+        enforce_phase0_params: bool = True,
     ):
         r"""
         Arguments used to define and configure a scheduled fine-tuning training session:
@@ -116,7 +118,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 :ref:`LR Scheduler Reinitialization<explicit-lr-reinitialization-schedule>` for more complex
                 schedule configurations (including per-phase LR scheduler reinitialization). If a schedule is not
                 provided, will generate and execute a default fine-tuning schedule using the provided
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule`. See
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule`. See
                 :ref:`the default schedule<index:The Default Fine-Tuning Schedule>`. Defaults to ``None``.
             max_depth: Maximum schedule depth to which the defined fine-tuning schedule should be executed. Specifying
                 -1 or an integer > (number of defined schedule layers) will result in the entire fine-tuning schedule
@@ -128,7 +130,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint`) checkpoint
                 before fine-tuning depth transitions. Defaults to ``True``.
             gen_ft_sched_only: If ``True``, generate the default fine-tuning schedule to ``Trainer.log_dir`` (it will be
-                named after your :external+pl:class:`~pytorch_lightning.core.module.LightningModule` subclass with
+                named after your :external+pl:class:`~lightning.pytorch.core.module.LightningModule` subclass with
                 the suffix ``_ft_schedule.yaml``) and exit without training. Typically used to generate a default
                 schedule that will be adjusted by the user before training. Defaults to ``False``.
             epoch_transitions_only: If ``True``, use epoch-driven stopping criteria exclusively (rather than composing
@@ -142,9 +144,9 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 ``lr_scheduler_init`` dictionary with a ``class_path`` key specifying the class of the lr scheduler
                 to be instantiated. Optionally, an ``init_args`` dictionary of arguments to initialize the lr scheduler
                 with may be included. Additionally, one may optionally include arguments to pass to PyTorch Lightning's
-                lr scheduler configuration :class:`~pytorch_lightning.utilities.types.LRSchedulerConfig` in the
+                lr scheduler configuration :class:`~lightning.pytorch.utilities.types.LRSchedulerConfig` in the
                 ``pl_lrs_cfg`` dictionary. By way of example, one could configure this dictionary via the
-                :external+pl:class:`~pytorch_lightning.cli.LightningCLI` with the following:
+                :external+pl:class:`~lightning.pytorch.cli.LightningCLI` with the following:
 
                 .. code-block:: yaml
 
@@ -186,11 +188,11 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                     (e.g. :external+torch:class:`~torch.optim.lr_scheduler.LambdaLR` is especially useful for this).
             strategy_adapter_cfg: A configuration dictionary that will be applied to the
                 :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` associated with the current training
-                :external+pl:class:`~pytorch_lightning.strategies.Strategy`. See the relevant
+                :external+pl:class:`~lightning.pytorch.strategies.Strategy`. See the relevant
                 :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` documentation for strategy-specific
                 configuration options. Defaults to None.
-            custom_strategy_adapter: A dictionary associating the canonical ``strategy_name`` of a
-                :external+pl:class:`~pytorch_lightning.strategies.Strategy` (potentially a custom user-registered one)
+            custom_strategy_adapter: A dictionary associating the canonical ``strategy_flag`` associated with a
+                :external+pl:class:`~lightning.pytorch.strategies.Strategy` (potentially a custom user-registered one)
                 to the fully qualified path of a
                 :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` subclass. This is an experimental
                 feature that is subject to change. Requires ``allow_untested`` to be set to ``True``. Defaults to None.
@@ -200,12 +202,19 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 will always apply the specified lambdas. Defaults to ``False``.
             logging_level: Sets the logging level for :class:`~finetuning_scheduler.fts.FinetuningScheduler`. Defaults
                 to ``INFO``.
+            enforce_phase0_params: Whether :class:`~finetuning_scheduler.fts.FinetuningScheduler` will reconfigure the
+                user-configured optimizer (configured via `configure_optimizers`) to optimize the parameters (and only
+                those parameters) scheduled to be optimized in phase 0 of the current fine-tuning schedule.
+                Reconfiguration will only take place if FTS discovers the set of parameters to be initially thawed
+                and present in the optimizer differs from the parameters specified in phase 0. Only the parameters
+                included in the optimizer are affected; the choice of optimizer, lr_scheduler etc. remains unaltered.
+                Defaults to ``True``.
 
         Attributes:
             _fts_state: The internal :class:`~finetuning_scheduler.fts.FinetuningScheduler` state.
             strategy_adapter_cfg: A configuration dictionary that will be applied to the
                 :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` associated with the current training
-                :external+pl:class:`~pytorch_lightning.strategies.Strategy`.
+                :external+pl:class:`~lightning.pytorch.strategies.Strategy`.
             epoch_transitions_only: Whether to use epoch-driven stopping criteria exclusively.
             base_max_lr: The default maximum learning rate to use for the parameter groups associated with each
                 scheduled fine-tuning depth if not explicitly specified in the fine-tuning schedule. If overridden to
@@ -224,7 +233,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         self.custom_strategy_adapter = custom_strategy_adapter
         self.allow_untested = allow_untested
         self.apply_lambdas_new_pgs = apply_lambdas_new_pgs
-        rz_logger = logging.getLogger("pytorch_lightning.utilities.rank_zero")
+        self.enforce_phase0_params = enforce_phase0_params
+        rz_logger = logging.getLogger("lightning.pytorch.utilities.rank_zero")
         rz_logger.setLevel(logging_level)
 
     @property
@@ -246,20 +256,17 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         return max(self.max_depth - self._fts_state._curr_depth, 0)
 
     @staticmethod
-    def _supported_strategy_types() -> Sequence[str]:
+    def _supported_strategy_flags() -> Sequence[str]:
         return (
-            "dp",
             "ddp",
             "ddp_find_unused_parameters_false",
+            "ddp_find_unused_parameters_true",
             "ddp_spawn",
             "ddp_fork",
             "ddp_notebook",
             "single_device",
-            # TODO: `native` suffix will be removed from `fsdp` strategies in 2.0
-            "fsdp_native",
-            "fsdp_native_full_shard_offload",
-            "ddp_sharded",  # TODO: remove in 2.0
-            "ddp_sharded_spawn"  # TODO: remove in 2.0,
+            "fsdp",
+            "fsdp_cpu_offload",
             # "deepspeed",  # relevant FTS strategy adapter not yet available, PRs welcome!
         )
 
@@ -268,8 +275,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         tuning schedule.
 
         Args:
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The target
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` to freeze parameters of
+            pl_module (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The target
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` to freeze parameters of
         """
         self.freeze(modules=pl_module, train_bn=False)
 
@@ -297,7 +304,13 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             assert self.pl_module.trainer.early_stopping_callback is not None
             self.pl_module.trainer.early_stopping_callback.final_phase = True  # type: ignore[attr-defined]
         assert self._fts_state._ft_sync_objects is not None
+        if self._fts_state._resume_fit_from_ckpt:
+            # ensure multi-phase training session loops are synchronized for a fresh epoch restart
+            self._maybe_sync_loops()
         FinetuningScheduler.sync(self._fts_state._ft_sync_objects, self._fts_state._ft_sync_props)
+        if self.pl_module._compiler_ctx and self.pl_module._compiler_ctx.get("compiler", None) == "dynamo":
+            # reset currently required as `AOTAutograd`` is getting confused by `requires_grad` alteration
+            torch._dynamo.reset()
         rank_zero_info(f"Multi-phase fine-tuned training continuing at level {self.curr_depth}.")
         if self.depth_remaining == 0:
             max_epochs_msg = f"`max_epochs` ({self.pl_module.trainer.fit_loop.max_epochs}) is reached."
@@ -326,13 +339,13 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         assert isinstance(self.pl_module, pl.LightningModule)
         assert isinstance(self.pl_module.trainer, pl.Trainer)
         if depth_sync:
-            thaw_layers = {d: l for d, l in self.ft_schedule.items() if d > self._fts_state._best_ckpt_depth}.items()
+            thaw_layers = {d: tl for d, tl in self.ft_schedule.items() if d > self._fts_state._best_ckpt_depth}.items()
         else:
             thaw_layers = {depth: self.ft_schedule[depth]}.items()
         for i, orig_next_tl in thaw_layers:
             next_tl = deepcopy(orig_next_tl)
-            next_tl["params"] = self.strategy_adapter.fts_optim_view(next_tl["params"])
             if i <= depth:
+                next_tl["params"] = self.strategy_adapter.fts_optim_transform(next_tl["params"])
                 _, self._fts_state._curr_thawed_params = self.strategy_adapter.exec_ft_phase(
                     self.pl_module, thaw_pl=next_tl["params"]
                 )
@@ -340,7 +353,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                     module=self.pl_module,
                     optimizer=optimizer,
                     thawed_pl=next_tl["params"],
-                    lr=next_tl["lr"],
+                    lr=next_tl.get("lr", optimizer.defaults["lr"]),
                     no_decay=getattr(self.pl_module, "no_decay", None),
                     apply_lambdas=self.apply_lambdas_new_pgs,
                 )
@@ -395,7 +408,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         self.pl_module.trainer._checkpoint_connector.restore_datamodule()
         self.pl_module.trainer._checkpoint_connector.restore_model()
         # we need to override checkpoint_connector.restore_training_state() to bypass loop restoration
-        # if additional customizations are required, may make sense to subclass CheckpointConnector at some point
+        # if additional customizations are required, may make sense to subclass _CheckpointConnector at some point
         self._restore_training_state()
         self.pl_module.trainer._checkpoint_connector.resume_end()
 
@@ -411,7 +424,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         checkpoint_connector.restore_precision_plugin_state()
 
         # checkpoint_connector.restore_training_state() would restore loops here
-        # self.restore_loops()
+        # checkpoint_connector.restore_loops()
 
         assert self.pl_module.trainer.state.fn is not None
         if self.pl_module.trainer.state.fn == TrainerFn.FITTING:
@@ -432,7 +445,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         """Reduce a transition decision across all world processes (effectively a global `any` collective)
 
         Args:
-            strategy (Strategy): The PL :external+pl:class:`~pytorch_lightning.strategies.Strategy` context to use.
+            strategy (Strategy): The PL :external+pl:class:`~lightning.pytorch.strategies.Strategy` context to use.
             decision (bool): The local process decision.
 
         Returns:
@@ -448,8 +461,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         to ``True`` in logging the monitored metric.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
         """
         early_stopping_callback = trainer.early_stopping_callback
         assert early_stopping_callback is not None
@@ -470,21 +483,23 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             early_stopping_callback._transition_es_phase()
 
     def _strategy_setup(self, trainer: "pl.Trainer") -> None:
-        """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used
+        """Validate a compatible :external+pl:class:`~lightning.pytorch.strategies.Strategy` strategy is being used
         and connects the relevant :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter`.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
 
         Raises:
             MisconfigurationException: If the
-                :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy being used is not currently
+                :external+pl:class:`~lightning.pytorch.strategies.Strategy` strategy being used is not currently
                 compatible with the :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback.
         """
         strategy = trainer.strategy
-        supported = [t.lower() for t in self._supported_strategy_types()]
-        if strategy.strategy_name and strategy.strategy_name not in supported:  # type: ignore[attr-defined]
+        connector_flag = getattr(trainer._accelerator_connector, "_strategy_flag", None)
+        strategy_flag = connector_flag.strategy_name if isinstance(connector_flag, Strategy) else connector_flag
+        supported = [t.lower() for t in self._supported_strategy_flags()]
+        if strategy_flag and strategy_flag not in supported:  # type: ignore[attr-defined]
             if not self.allow_untested:
                 raise MisconfigurationException(
                     "FTS is has not yet been adapted for or rigorously tested using the specified distributed strategy."
@@ -495,36 +510,36 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             else:
                 warn_msg = (
                     "Allowing untested strategy"
-                    f" '{strategy.strategy_name}' because ``allow_untested`` is ``True``."  # type: ignore[attr-defined]
+                    f" '{strategy}' because ``allow_untested`` is ``True``."  # type: ignore[attr-defined]
                 )
                 rank_zero_warn(warn_msg)
         if self.custom_strategy_adapter:
-            strategy_cls = self._import_strategy_adapter(strategy.strategy_name, self.custom_strategy_adapter)
+            strategy_cls = self._import_strategy_adapter(strategy_flag, self.custom_strategy_adapter)
             rank_zero_info(
                 f"Imported custom strategy adapter class type `{strategy_cls}` associated with the current strategy"
-                f" `{strategy.strategy_name}`."
+                f" `{strategy_flag}`."
             )
         else:
-            strategy_cls = STRATEGY_ADAPTERS.get(strategy.strategy_name, StrategyAdapter)
+            strategy_cls = STRATEGY_ADAPTERS.get(strategy_flag, StrategyAdapter)
         self.strategy_adapter = strategy_cls(**self.strategy_adapter_cfg)
         self.strategy_adapter.connect(self)
 
     def setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: str) -> None:
-        """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used and
+        """Validate a compatible :external+pl:class:`~lightning.pytorch.strategies.Strategy` strategy is being used and
         ensure all :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback dependencies are met. If a valid
         configuration is present, then either dump the default fine-tuning schedule OR
         1. configure the :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping`
         callback (if relevant)
         2. initialize the :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`
-        3. freeze the target :external+pl:class:`~pytorch_lightning.core.module.LightningModule` parameters
+        3. freeze the target :external+pl:class:`~lightning.pytorch.core.module.LightningModule` parameters
         Finally, initialize the :class:`~finetuning_scheduler.fts.FinetuningScheduler`
         training session in the training environment.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
             stage: The ``RunningStage.{SANITY_CHECKING,TRAINING,VALIDATING}``. Defaults to None.
 
         Raises:
@@ -554,10 +569,10 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         :class:`~finetuning_scheduler.fts.FinetuningScheduler` is present.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
 
         Raises:
             MisconfigurationException: If more than 1 optimizers are configured indicates a configuration error
@@ -586,6 +601,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             Dict[str, Any]: The :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback state dictionary
                 that will be added to the checkpoint
         """
+        # callback state such as `_ft_init_epoch` does not currently need to be persisted
         assert self.pl_module is not None and self.pl_module.trainer is not None
         trainer = self.pl_module.trainer
         checkpoint_callback = trainer.checkpoint_callback
@@ -628,8 +644,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         ``True``)
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
         """
         assert self.pl_module is not None
         assert isinstance(self.ft_schedule, Dict)
@@ -664,27 +680,29 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         scheduled fine-tuning level and store the updated optimizer configuration before continuing training
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
         """
         # if resuming from a ckpt, we need to sync fts_state
         if self._fts_state._resume_fit_from_ckpt:
             self.step()
             self._fts_state._resume_fit_from_ckpt = False
         # increment ft_epoch on each train epoch
-        if trainer.current_epoch > 0:
+        assert isinstance(self._fts_state._ft_init_epoch, int)
+        if trainer.current_epoch > self._fts_state._ft_init_epoch:
             assert self._fts_state._ft_sync_objects is not None
             self.sync(self._fts_state._ft_sync_objects, self._fts_state._ft_sync_props)
         if self.should_transition(trainer):
             self._fts_state._curr_depth += 1  # increment depth
             self.step()
             rank_zero_debug(
-                f"Current logical parameters thawed by Fine-Tuning Scheduler: "
-                f"{self.strategy_adapter.logical_param_translation(self._fts_state._curr_thawed_params)}."
-                f"Current actual parameters thawed by Fine-Tuning Scheduler: {self._fts_state._curr_thawed_params}. "
                 f"Current depth is {self.curr_depth}."
+                "\nCurrent logical parameters thawed by Fine-Tuning Scheduler:\n "
+                f"{pformat(self.strategy_adapter.logical_param_translation(self._fts_state._curr_thawed_params))}."
+                "\nCurrent actual parameters thawed by Fine-Tuning Scheduler:\n"
+                f"{pformat(self._fts_state._curr_thawed_params)}. "
             )
             if not self.epoch_transitions_only:
                 assert isinstance(trainer.early_stopping_callback, FTSEarlyStopping)
@@ -707,10 +725,10 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         global fine-tuning steps taken
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module  (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module  (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
             optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
                 :external+torch:class:`~torch.optim.Optimizer` to which parameter groups will be configured and added.
         """
@@ -721,9 +739,9 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         to ensure final training state is consistent with epoch semantics.
 
         Args:
-            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module  (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer: The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module  (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
         """
         assert self._fts_state._ft_sync_objects is not None
         self.sync(self._fts_state._ft_sync_objects, self._fts_state._ft_sync_props)
