@@ -23,30 +23,31 @@ import pathlib
 import re
 import warnings
 from abc import ABC, abstractmethod
-from collections import Counter
+from collections import Counter, defaultdict
 from collections.abc import KeysView
 from copy import copy
 from dataclasses import dataclass, field, fields
 from functools import reduce
+from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
-import pytorch_lightning as pl
+import lightning.pytorch as pl
 import torch
 import yaml
-from lightning_fabric.utilities import rank_zero_info, rank_zero_only, rank_zero_warn
-from lightning_fabric.utilities.cloud_io import get_filesystem
-from lightning_fabric.utilities.distributed import _distributed_available
-from lightning_fabric.utilities.types import _TORCH_LRSCHEDULER, ReduceLROnPlateau
-from pytorch_lightning.callbacks import Callback
-from pytorch_lightning.callbacks.early_stopping import EarlyStopping
-from pytorch_lightning.callbacks.lr_monitor import LearningRateMonitor
-from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
-from pytorch_lightning.core.optimizer import _MockOptimizer
-from pytorch_lightning.trainer.states import TrainerFn
-from pytorch_lightning.utilities import find_shared_parameters
-from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.rank_zero import rank_zero_debug
-from pytorch_lightning.utilities.types import LRSchedulerConfig
+from lightning.fabric.utilities import rank_zero_info, rank_zero_only, rank_zero_warn
+from lightning.fabric.utilities.cloud_io import get_filesystem
+from lightning.fabric.utilities.distributed import _distributed_available
+from lightning.fabric.utilities.types import _TORCH_LRSCHEDULER, ReduceLROnPlateau
+from lightning.pytorch.callbacks import Callback
+from lightning.pytorch.callbacks.early_stopping import EarlyStopping
+from lightning.pytorch.callbacks.lr_monitor import LearningRateMonitor
+from lightning.pytorch.callbacks.model_checkpoint import ModelCheckpoint
+from lightning.pytorch.core.optimizer import _MockOptimizer
+from lightning.pytorch.trainer.states import TrainerFn
+from lightning.pytorch.utilities import find_shared_parameters
+from lightning.pytorch.utilities.exceptions import MisconfigurationException
+from lightning.pytorch.utilities.rank_zero import rank_zero_debug
+from lightning.pytorch.utilities.types import LRSchedulerConfig
 from torch import Tensor
 from torch.nn import Module
 from torch.optim.optimizer import Optimizer
@@ -58,7 +59,7 @@ log = logging.getLogger(__name__)
 CALLBACK_DEP_PARENTS = {"ModelCheckpoint": ModelCheckpoint, "EarlyStopping": EarlyStopping}
 CALLBACK_ATTRS = ("ft_schedule", "max_depth")
 TARGET_CALLBACK_REF = "FinetuningScheduler"
-STRATEGY_ADAPTERS = {"fsdp_native": FSDPStrategyAdapter}
+STRATEGY_ADAPTERS = {"fsdp": FSDPStrategyAdapter}
 
 
 @dataclass
@@ -76,6 +77,7 @@ class FTSState:
         ("epoch_loop.global_step", "_ft_global_steps"),
     )
     _ft_sync_objects: Optional[Tuple] = None
+    _ft_init_epoch: Optional[int] = None
     _curr_thawed_params: List = field(default_factory=list)
     _fts_ckpt_metadata: Dict = field(default_factory=dict)
 
@@ -146,7 +148,7 @@ class CallbackResolverMixin(ABC):
         callback.
 
         Args:
-            trainer (pl.Trainer): The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object.
+            trainer (pl.Trainer): The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object.
             reconnect (bool, optional): Whether to check for an updated target callback object even if one is already
                 resolved. Predominantly useful in the context of testing. Defaults to False.
 
@@ -175,13 +177,13 @@ class CallbackResolverMixin(ABC):
 
 class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
     r"""
-    Extends/specializes :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` to facilitate
+    Extends/specializes :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping` to facilitate
     multi-phase scheduled fine-tuning.
 
     Adds :attr:`es_phase_complete`, :attr:`final_phase` and :attr:`finetuningscheduler_callback` attributes and modifies
     ``EarlyStopping._evaluate_stopping_criteria`` to enable multi-phase behavior. Usage of
     :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` is identical to
-    :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` except the former will evaluate the
+    :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping` except the former will evaluate the
     specified early stopping criteria at every scheduled phase.
     :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` will automatically be
     used if a :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback is detected
@@ -190,7 +192,7 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
     .. note::
 
        For detailed usage information,
-       see :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`.
+       see :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping`.
 
     .. note::
 
@@ -209,7 +211,7 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
                 Used to determine if the current phase's early stopping criteria have been met.
             final_phase (bool):
                 Used to indicate whether the current phase is the final scheduled phase.
-            finetuningscheduler_callback (pytorch_lightning.callbacks.Callback):
+            finetuningscheduler_callback (lightning.pytorch.callbacks.Callback):
                 Reference to the :class:`~finetuning_scheduler.fts.FinetuningScheduler`
                 callback being used.
             reduce_transition_decisions (bool):
@@ -217,7 +219,7 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
                 being synchronized (via ``sync_dist`` being set to ``True`` when logging).
             check_on_train_epoch_end (bool): Whether to run early stopping check at the end of the training epoch. If
                 this is ``False``, then the check runs at the end of the validation. Defaults to ``None`` similar to
-                :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` but is set to
+                :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping` but is set to
                 ``False`` during setup unless overridden.
         """
         super().__init__(*args, **kwargs)
@@ -240,9 +242,9 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
         over all distributed training processes.
 
         Args:
-            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module  (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer: The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module  (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
         """
         if trainer.state.fn == TrainerFn.FITTING:
             self.reduce_transition_decisions = self._check_sync_dist(trainer)
@@ -253,7 +255,7 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
         callback need to be reduced over all distributed training processes.
 
         Args:
-            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            trainer: The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
 
         Returns:
             bool: Whether to reduce transition decisions for this callback over all training processes
@@ -342,18 +344,18 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
 
 class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
     r"""
-    Extends/specializes :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint` to facilitate
+    Extends/specializes :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint` to facilitate
     multi-phase scheduled fine-tuning. Overrides the
     ``state_dict`` and ``load_state_dict`` hooks to maintain additional state (:attr:`current_ckpt_depth`,
     :attr:`best_ckpt_depth`, :attr:`finetuningscheduler_callback`). Usage of
     :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint` is identical to
-    :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint` and
+    :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint` and
     :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint` will automatically be used if a
     :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback is detected.
 
     .. note::
         For detailed usage information, see
-        :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`.
+        :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint`.
 
     .. note::
 
@@ -374,12 +376,12 @@ class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
                 Used to track the depth of most recently saved checkpoint
             best_ckpt_depth (int):
                 Used to track the depth of the best known checkpoint (it may be from a different training depth)
-            finetuningscheduler_callback (pytorch_lightning.callbacks.Callback):
+            finetuningscheduler_callback (lightning.pytorch.callbacks.Callback):
                 Reference to the :class:`~finetuning_scheduler.fts.FinetuningScheduler`
                 callback being used.
             save_on_train_epoch_end (Optional[bool]): Whether to run checkpointing at the end of the training epoch.
                 If this is ``False``, then the check runs at the end of the validation. Defaults to ``None`` similar to
-                :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint` but is set to
+                :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint` but is set to
                 ``False`` during setup unless overridden.
         """
         super().__init__(*args, **kwargs)
@@ -391,7 +393,7 @@ class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
         """Verify a valid callback configuration is present before beginning training.
 
         Args:
-            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            trainer: The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
 
         Raises:
             MisconfigurationException:
@@ -426,7 +428,7 @@ class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
         super().setup(trainer, pl_module, stage)
 
     def state_dict(self) -> Dict[str, Any]:
-        """Overrides. :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`'s
+        """Overrides. :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint`'s
         ``state_dict`` method to maintain multi-phase training depth state.
 
         Returns:
@@ -453,7 +455,7 @@ class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
         }
 
     def load_state_dict(self, state_dict: Dict[str, Any]) -> None:
-        """Overrides :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`'s
+        """Overrides :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint`'s
         ``load_state_dict`` method to load multi-phase training depth state.
 
         Args:
@@ -756,7 +758,7 @@ class ScheduleParsingMixin(ABC):
             self._rewrite_schedule(err_msg=err_msg)
 
     def _validate_epoch_transitions(self) -> None:
-        """If not composing :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` and
+        """If not composing :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping` and
         epoch-driven stopping criteria (the default behavior) but instead specifying exclusively epoch-driven
         transitions ( :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.epoch_transitions_only` is
         ``True``), ensure the specified schedule specifies transitions for every phase.
@@ -871,7 +873,7 @@ class ScheduleParsingMixin(ABC):
 
         Args:
             new_lr_scheduler (Dict): A dictionary defining the new lr scheduler configuration to be initialized.
-            trainer (pl.Trainer): The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object.
+            trainer (pl.Trainer): The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object.
             optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
                 :external+torch:class:`~torch.optim.Optimizer` around which the new lr scheduler will be wrapped.
         """
@@ -889,7 +891,6 @@ class ScheduleParsingMixin(ABC):
         if "pl_lrs_cfg" in new_lr_scheduler.keys():
             new_lr_scheduler["pl_lrs_cfg"] = self._update_pl_lrs(new_lr_scheduler["pl_lrs_cfg"], lrs_class=lrs_class)
         new_lrs_config = LRSchedulerConfig(
-            opt_idx=0,
             scheduler=lrs_class(
                 optimizer=optimizer, **lr_scheduler_init.get("init_args", {})
             ),  # type: ignore[arg-type]
@@ -1066,6 +1067,10 @@ class ScheduleImplMixin(ABC):
     reinit_lr_cfg: Optional[Dict]
     max_depth: int
     _fts_state: FTSState
+    PHASE_0_DIVERGENCE_MSG = (
+        "After executing the provided `configure_optimizers` method, the optimizer state differs from the configuration"
+        " FinetuningScheduler expected at the beginning of scheduled fine-tuning (phase 0).\n"
+    )
 
     @property
     @abstractmethod
@@ -1083,6 +1088,8 @@ class ScheduleImplMixin(ABC):
         2. Prepare the first scheduled fine-tuning level, unfreezing the relevant parameters.
         """
         self.strategy_adapter.on_before_init_fts()
+        if not self._fts_state._ft_init_epoch:
+            self._fts_state._ft_init_epoch = max(self.pl_module.trainer.current_epoch, 0)
         self.init_ft_sched()
         self.strategy_adapter.on_after_init_fts()
 
@@ -1165,7 +1172,7 @@ class ScheduleImplMixin(ABC):
 
         Returns:
             os.PathLike: The path to the generated schedule, by default ``Trainer.log_dir`` and named after the
-            :external+pl:class:`~pytorch_lightning.core.module.LightningModule` subclass in use with the suffix
+            :external+pl:class:`~lightning.pytorch.core.module.LightningModule` subclass in use with the suffix
             ``_ft_schedule.yaml``)
         """
         dump_path = pathlib.Path(dump_loc)
@@ -1188,7 +1195,7 @@ class ScheduleImplMixin(ABC):
             dump_loc: The directory to which the generated schedule (.yaml) should be written
         Returns:
             os.PathLike: The path to the generated schedule, by default ``Trainer.log_dir`` and named after the
-            :external+pl:class:`~pytorch_lightning.core.module.LightningModule` subclass in use with the suffix
+            :external+pl:class:`~lightning.pytorch.core.module.LightningModule` subclass in use with the suffix
             ``_ft_schedule.yaml``)
         """
         # Note: This initial default fine-tuning schedule generation approach is intentionally simple/naive but is
@@ -1209,8 +1216,8 @@ class ScheduleImplMixin(ABC):
         if len(model_params) % 2 == 1:
             param_lists.append([model_params[-1][0]])
         layer_config = {}
-        for i, l in enumerate(param_lists):
-            layer_config[i] = {"params": l}
+        for i, param_l in enumerate(param_lists):
+            layer_config[i] = {"params": param_l}
         schedule_name = f"{module.__class__.__name__}_ft_schedule.yaml"
         assert dump_loc is not None
         return ScheduleImplMixin.save_schedule(schedule_name, layer_config, dump_loc)
@@ -1265,7 +1272,7 @@ class ScheduleImplMixin(ABC):
         for i, next_tl in self.ft_schedule.items():  # type: ignore[union-attr]
             if i <= depth:
                 _, self._fts_state._curr_thawed_params = self.strategy_adapter.exec_ft_phase(
-                    self.pl_module, thaw_pl=self.strategy_adapter.fts_optim_view(next_tl["params"])
+                    self.pl_module, thaw_pl=self.strategy_adapter.fts_optim_transform(next_tl["params"])
                 )
 
     @staticmethod
@@ -1388,6 +1395,20 @@ class ScheduleImplMixin(ABC):
             for o, a in zip(objs, attrs):
                 setattr(o, a, agg)
 
+    def _maybe_sync_loops(self) -> None:
+        """Synchronize total and current progress loops for the restart of a multi-phase training session."""
+        assert self.pl_module._trainer is not None
+        fit_loop = self.pl_module._trainer.fit_loop
+        if fit_loop.epoch_loop.restarting:  # if ``True``, we haven't completed resetting state
+            # since we're restoring from a checkpoint saved prior to processed and completed incrementing
+            fit_loop.epoch_progress.increment_processed()
+            fit_loop.epoch_progress.increment_completed()
+            # ensure current and total are synchronized for the continuation of our multi-phase fine-tuning session
+            fit_loop.epoch_progress.current = copy(fit_loop.epoch_progress.total)
+            # restarting outside of epoch end is not supported so the assumption here is to start with a fresh epoch
+            fit_loop.epoch_loop.restarting = False
+            fit_loop.epoch_loop.val_loop._restarting = False
+
     def _inspect_fts_opt_state(self) -> Tuple:
         """Distills relevant initialized optimizer state for validation prior to fit start.
 
@@ -1398,11 +1419,50 @@ class ScheduleImplMixin(ABC):
         opt = self.pl_module.trainer.optimizers[0]
         sched = self.ft_schedule
         no_grad_cnt = len([p for pg in opt.param_groups for p in pg["params"] if not p.requires_grad])
-        req_grad_opt = len([p for pg in opt.param_groups for p in pg["params"] if p.requires_grad])
-        init_ft_cnt = len(self.strategy_adapter.fts_optim_view(sched[0]["params"]))
-        total_ft_cnt = len([p for phase in sched for p in self.strategy_adapter.fts_optim_view(sched[phase]["params"])])
-        expected_grad_params = req_grad_opt == init_ft_cnt
-        return no_grad_cnt, init_ft_cnt, total_ft_cnt, req_grad_opt, expected_grad_params
+        init_ft_cnt = len(self.strategy_adapter.fts_optim_inspect(sched[0]["params"]))
+        total_ft_cnt = len(
+            [p for phase in sched for p in self.strategy_adapter.fts_optim_inspect(sched[phase]["params"])]
+        )
+        optim_grad_param_set = {p for pg in opt.param_groups for p in pg["params"] if p.requires_grad}
+        sched_grad_param_set = {
+            p
+            for n, p in self.pl_module.named_parameters()
+            if n in self.strategy_adapter.fts_optim_inspect(sched[0]["params"])
+        }
+        expected_params_sym_diff = optim_grad_param_set ^ sched_grad_param_set
+        p_diff_summary = defaultdict(list)
+        if expected_params_sym_diff:
+            for n, p in self.pl_module.named_parameters():
+                if p in optim_grad_param_set:
+                    p_diff_summary["optim_params"].append(n)
+                if p in sched_grad_param_set:
+                    p_diff_summary["phase_0_params"].append(n)
+        p_diff_summary = {k: self.strategy_adapter.logical_param_translation(v) for k, v in p_diff_summary.items()}
+        return no_grad_cnt, init_ft_cnt, total_ft_cnt, p_diff_summary
+
+    @staticmethod
+    def _grad_mismatch_feedback(w_msg: str, param_diff_summary: Dict) -> str:
+        """Assemble feedback for the user regarding the current optimizer state's divergence from the state
+        expected in scheduled fine-tuning phase 0 (with respect to thawed parameters).
+
+        Args:
+            w_msg (str): Initial warning message context.
+            param_diff_summary (Dict): A summary of the current optimizer state's divergence from the state expected in
+                scheduled fine-tuning phase 0 (with respect to thawed parameters).
+
+        Returns:
+            str: The user feedback warning with appropriate context.
+        """
+        w_msg += (
+            " a differing set of trainable parameters. Please find below a summary of the differences between"
+            " the currently thawed parameters in the optimizer and those scheduled to be optimized during fine-tuning"
+            " phase 0: \n"
+            "Currently thawed parameters included in the optimizer:\n"
+            f"{pformat(param_diff_summary['optim_params'])}{os.linesep}"
+            "Parameters expected to be thawed and optimized in phase 0:\n"
+            f"{pformat(param_diff_summary['phase_0_params'])}{os.linesep}"
+        )
+        return w_msg
 
     def _validate_opt_init(self) -> None:
         """Validate the user-initialized optimizer state (necessary for fine-tuning phase 0) and warn user if
@@ -1412,37 +1472,38 @@ class ScheduleImplMixin(ABC):
             optimizer (Optimizer): The optimizer initialized.
             ft_schedule (Dict): The fine-tuning schedule to be inspected vis-a-vis the optimizer state.
         """
-        no_grad_cnt, init_ft_cnt, total_ft_cnt, req_grad_opt, expected_grad_params = self._inspect_fts_opt_state()
-        if no_grad_cnt > 0 or not expected_grad_params:
-            warn_msg = (
-                f"FinetuningScheduler configured the provided model to have {init_ft_cnt} trainable parameters"
-                f" in phase 0 (the initial training phase) but the optimizer has subsequently been initialized with"
-            )
-            if not expected_grad_params:
-                warn_msg += f" {req_grad_opt} trainable parameters. If you have manually"
-                if req_grad_opt > init_ft_cnt:
-                    warn_msg += (
-                        " added additional trainable parameters you may want to ensure the manually added new trainable"
-                        f" parameters do not collide with the {total_ft_cnt} parameters FinetuningScheduler has been"
-                        " scheduled to thaw in the provided schedule."
-                    )
-                else:
-                    warn_msg += (
-                        " removed trainable parameters, you may want to update phase 0 of the provided fine-tuning"
-                        " schedule accordingly"
-                    )
+        no_grad_cnt, init_ft_cnt, total_ft_cnt, param_diff_summary = self._inspect_fts_opt_state()
+        if param_diff_summary or no_grad_cnt > 0:
+            if self.enforce_phase0_params:
+                # implemented in `StrategyAdapter` since override behavior may be strategy-dependent in the future
+                self.strategy_adapter.phase0_optimizer_override()
             else:
-                warn_msg += (
-                    f" {no_grad_cnt} additional parameters that do not require a gradient. If non-intentional, this"
-                    " state is commonly caused by failing to filter out parameters that do not require a gradient when"
-                    " initializing the optimizer (e.g.,"
-                    " `parameters = list(filter(lambda x: x.requires_grad, self.parameters()))`"
-                    f" If you intended to initialize the optimizer with parameters that do not require a"
-                    f" gradient you may want to ensure they are not included in the {total_ft_cnt} parameters that the"
-                    " FinetuningScheduler is currently configured to thaw (sum of all phases) to avoid triggering a "
-                    " parameter collision and training failure in pytorch during a future fine-tuning phase."
+                w_msg = ScheduleImplMixin.PHASE_0_DIVERGENCE_MSG + (
+                    " Since `enforce_phase0_params` is currently set to `False`, FinetuningScheduler will not override"
+                    " the user-configured optimizer configuration to enforce the expected phase 0 configuration of"
+                    " thawed parameters."
+                    "\n\n"
+                    "HINT: Leaving `enforce_phase0_params` to its default (`True`) will avoid discrepancies like this"
+                    " in the majority of use cases. If that solution is not desired or sufficient, please find more"
+                    " detailed information about the configuration divergence below. \n\n"
+                    f"In this case, FinetuningScheduler configured the provided model to have {init_ft_cnt} trainable"
+                    " parameters in phase 0 (the initial training phase) but the optimizer has subsequently been"
+                    " initialized with"
                 )
-            rank_zero_warn(warn_msg)
+                if param_diff_summary:
+                    w_msg = ScheduleImplMixin._grad_mismatch_feedback(w_msg, param_diff_summary)
+                if no_grad_cnt > 0:
+                    w_msg += (
+                        f"Also note that there are {no_grad_cnt} parameters in the optimizer that do not require a"
+                        " gradient. If non-intentional, this state is commonly caused by failing to filter out"
+                        " parameters that do not require a gradient when initializing the optimizer (e.g.,"
+                        " `parameters = list(filter(lambda x: x.requires_grad, self.parameters()))`. If you intended to"
+                        " initialize the optimizer with parameters that do not require a gradient you may want to"
+                        f" ensure they are not included in the {total_ft_cnt} parameters that the FinetuningScheduler"
+                        " is currently configured to thaw (sum of all phases) to avoid triggering a parameter collision"
+                        " and training failure in pytorch during a future fine-tuning phase."
+                    )
+                rank_zero_warn(w_msg)
 
 
 class CallbackDepMixin(ABC):
@@ -1465,7 +1526,7 @@ class CallbackDepMixin(ABC):
         and scheduled fine-tuning capabilities.
 
         Args:
-            trainer (pl.Trainer):  The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object to
+            trainer (pl.Trainer):  The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object to
                 inspect the callbacks of
 
         Returns:
@@ -1482,7 +1543,7 @@ class CallbackDepMixin(ABC):
         """Validate multiple instances of a given user-provided callback dependency parent are not present.
 
         Args:
-            trainer (pl.Trainer): The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object to
+            trainer (pl.Trainer): The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object to
                 inspect the callbacks of
 
         Raises:
@@ -1527,10 +1588,10 @@ class CallbackDepMixin(ABC):
         and configuring them if necessary.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
-                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
-                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            trainer (:external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer`): The
+                :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object
+            pl_module (:external+pl:class:`~lightning.pytorch.core.module.LightningModule`): The
+                :external+pl:class:`~lightning.pytorch.core.module.LightningModule` object
             stage: The ``RunningStage.{SANITY_CHECKING,TRAINING,VALIDATING}``. Defaults to None.
         """
         trainer.callbacks, added_es_fts, added_ckpt_fts = self._configure_callback_deps(trainer)
@@ -1542,13 +1603,13 @@ class CallbackDepMixin(ABC):
             trainer.early_stopping_callback.setup(trainer, pl_module, stage)  # type: ignore[union-attr]
 
     def _configure_callback_deps(self, trainer: "pl.Trainer") -> Tuple[List[Callback], bool, bool]:
-        """Ensures FTSCheckpoint and :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`
+        """Ensures FTSCheckpoint and :external+pl:class:`~lightning.pytorch.callbacks.early_stopping.EarlyStopping`
         callbacks are present and configured, removing any.
 
-        :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`s if present.
+        :external+pl:class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint`s if present.
 
         Args:
-            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object that may have its
+            trainer: The :external+pl:class:`~lightning.pytorch.trainer.trainer.Trainer` object that may have its
                 callbacks list altered.
 
         Returns:
